@@ -35,13 +35,14 @@ class ConfigDialog(QtGui.QDialog):
         self.setLayout(layout)
 
     def doOk(self):
-        self.parent.configuration.set("Settings", "fullscreen", str(self.settings.fullscreenCheckBox.isChecked()))
-        self.parent.configuration.set("Settings", "screenAlwaysOn", str(self.settings.screenOnCheckBox.isChecked()))
-        self.parent.configuration.set("Settings", "showDate", str(self.settings.showDateBox.isChecked()))
-        self.parent.configuration.set("Settings", "soundPath", str(self.sounds.path.text()))
-        self.parent.configuration.set("Settings", "autostopalarm", str(self.settings.autoStopAlarmCheckBox.isChecked()))
-        self.parent.configuration.set("Settings", "themePath", str(self.themes.path.text()))
-        self.parent.soundPath = self.sounds.path.text()
+        self.parent.configuration.fullscreen = self.settings.fullscreenCheckBox.isChecked()
+        self.parent.configuration.screenalwayson = self.settings.screenOnCheckBox.isChecked()
+        self.parent.configuration.showdate = self.settings.showDateBox.isChecked()
+        self.parent.configuration.soundpath = str(self.sounds.path.text())
+        self.parent.configuration.autostopalarm = self.settings.autoStopAlarmCheckBox.isChecked()
+        self.parent.configuration.themepath = str(self.themes.path.text())
+        self.parent.configuration.volume = self.sounds.volumeSlider.value()
+        self.parent.configuration.soundpath = str(self.sounds.path.text())
         self.accept()
 
 class SettingsTab(QtGui.QWidget):
@@ -54,13 +55,13 @@ class SettingsTab(QtGui.QWidget):
 
         self.parent = p
         self.fullscreenCheckBox = QtGui.QCheckBox("Fullscreen")
-        self.fullscreenCheckBox.setChecked(self.parent.configuration.getboolean("Settings", "fullscreen"))
+        self.fullscreenCheckBox.setChecked(self.parent.configuration.fullscreen)
         self.screenOnCheckBox = QtGui.QCheckBox("Screen always on")
-        self.screenOnCheckBox.setChecked(self.parent.configuration.getboolean("Settings", "screenAlwaysOn"))
+        self.screenOnCheckBox.setChecked(self.parent.configuration.screenalwayson)
         self.showDateBox = QtGui.QCheckBox("Display date")
-        self.showDateBox.setChecked(self.parent.configuration.getboolean("Settings", "showDate"))
+        self.showDateBox.setChecked(self.parent.configuration.showdate)
         self.autoStopAlarmCheckBox = QtGui.QCheckBox("Turn Alarm off after 60 Mimutes")
-        self.autoStopAlarmCheckBox.setChecked(self.parent.configuration.getboolean("Settings", "autostopalarm"))
+        self.autoStopAlarmCheckBox.setChecked(self.parent.configuration.autostopalarm)
         
         layout = QtGui.QVBoxLayout()
         layout.addWidget(self.fullscreenCheckBox)
@@ -233,22 +234,41 @@ class SoundsTab(QtGui.QWidget):
     """
     Tab for sound settings
     """
-
+    def volume_changed(self):
+        self.volumeLabel.setText("Alarm volume: " + str(self.volumeSlider.value()) + "%")
+        
     def __init__(self, p, parent=None):
         super(SoundsTab, self).__init__(parent)
 
         self.parent = p
+        self.volume = self.parent.configuration.volume
+        
+        scrollArea = QtGui.QScrollArea()
+        layout = QtGui.QGridLayout()
+        layout2 = QtGui.QVBoxLayout()
+        layout.addWidget(scrollArea)
+        widget = QtGui.QWidget()
+        widget.resize(700, 300)
 
-        label = QtGui.QLabel("Stream-URL(http) or Playlist(.m3u):")
+        label = QtGui.QLabel("Stream-URL(http) or playlist(.m3u):")
         self.path = QtGui.QLineEdit()
-        self.path.setText(self.parent.configuration.get("Settings", "soundPath"))
-        button = QtGui.QPushButton("Choose Playlist(.m3u)")
+        self.path.setText(self.parent.configuration.soundpath)
+        button = QtGui.QPushButton("Choose playlist(.m3u)")
         button.clicked.connect(self.openDialog)
+        
+        self.volumeSlider = QtGui.QSlider(QtCore.Qt.Horizontal, self)
+        self.volumeSlider.setValue(self.volume)
+        self.volumeLabel = QtGui.QLabel("Alarm volume: " + str(self.volumeSlider.value()) + "%")
+        self.volumeSlider.valueChanged.connect(self.volume_changed)
 
-        layout = QtGui.QVBoxLayout()
-        layout.addWidget(label)
-        layout.addWidget(self.path)
-        layout.addWidget(button)
+        layout2.addWidget(label)
+        layout2.addWidget(self.path)
+        layout2.addWidget(button)
+        layout2.addWidget(self.volumeLabel)
+        layout2.addWidget(self.volumeSlider)
+        widget.setLayout(layout2)
+        scrollArea.setWidget(widget)
+        layout.addWidget(scrollArea, 0, 0)
         self.setLayout(layout)
 
     def openDialog(self):
@@ -269,7 +289,7 @@ class ThemesTab(QtGui.QWidget):
         self.parent = p
 
         self.path = QtGui.QLineEdit()
-        self.path.setText(self.parent.configuration.get("Settings", "themePath"))
+        self.path.setText(self.parent.configuration.themepath)
         button = QtGui.QPushButton("Choose Directory containing the theme")
         button.clicked.connect(self.openDialog)
 
