@@ -3,7 +3,6 @@
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtGui import QTabWidget, QColor, QPalette, QLabel, QPixmap
 from dialog import ConfigDialog
-import ConfigParser
 import os
 import shutil
 import wakeupalarm
@@ -45,7 +44,7 @@ class MainWindow(QtGui.QWidget):
     
     def __init__(self):
         super(MainWindow, self).__init__()
-        self.configuration = Configuration()
+        self.configuration = configuration.Configuration()
 
         from player import AudioPlayer        
         self.audioPlayer = AudioPlayer()
